
# bcond_without is built by default, unless --without X is passed
# bcond_with is built only when --with X is passed to build
%bcond_with    SYSTEMTEST
%bcond_without GSSTSIG
%bcond_without JSON
# FIXME: Not ready. Should it be worked on?
%bcond_with    DLZ
# New MaxMind GeoLite support
%bcond_without GEOIP2
# Disabled temporarily until kyua is fixed on rawhide, bug #1926779
%bcond_without UNITTEST
%bcond_without LMDB
%bcond_with DOC
%bcond_without MAN

%define major_version 9.18.33
#define patch_version P4
%define dashpatch %{?patch_version:-%patch_version}%nil
%define dotpatch %{?patch_version:.%patch_version}%nil
%define chroot_prefix /var/named/chroot
%define chroot_create_directories \\\
	/dev /run/named %{_localstatedir}/{log,named,tmp} \\\
	%{_sysconfdir}/{crypto-policies/back-ends,pki/dnssec-keys,named} \\\
	%{_libdir}/bind %{_libdir}/named %{_datadir}/GeoIP

%define libname         %mklibname bind %version

# libisc-nosym requires to be linked with unresolved symbols
# When libisc-nosym linking is fixed, it can be defined to 1
# Visit https://bugzilla.redhat.com/show_bug.cgi?id=1540300
%define _disable_ld_no_undefined 1

Name:       bind
Version:    %{major_version}%{dotpatch}
Release:    %mkrel 1
Summary:    A DNS (Domain Name System) server
License:    MPLv2.0
Group:      System/Servers
URL:        https://www.isc.org/bind
Source0:    https://downloads.isc.org/isc/bind9/%{version}/%{name}-%{version}.tar.xz

Source1:  named.sysconfig
Source2:  https://downloads.isc.org/isc/bind9/%{version}/%{name}-%{version}.tar.xz.asc
Source3:  named.logrotate
Source4:  https://downloads.isc.org/isc/pgpkeys/codesign2021.txt
Source16: named.conf
# Refresh by command: dig @a.root-servers.net. +tcp +norec
# or from URL
Source17: https://www.internic.net/domain/named.root
Source18: named.localhost
Source19: named.loopback
Source20: named.empty
Source23: named.rfc1912.zones
Source25: named.conf.sample
Source27: named.root.key
Source35: bind.tmpfiles
Source36: trusted-key.key
Source37: named.service
Source38: named-chroot.service
Source41: setup-named-chroot.sh
Source42: generate-rndc-key.sh
Source43: named.rwtab
Source44: named-chroot-setup.service
Source46: named-setup-rndc.service
Source48: setup-named-softhsm.sh
Source49: named-chroot.files

# fedora patches
# FIXME: Is this still required?
Patch10: bind-9.5-PIE.patch
# https://bugzilla.redhat.com/show_bug.cgi?id=2122010
Patch26: bind-9.18-unittest-netmgr-unstable.patch

# 
# Security Patches
# Patch100 -> ...
#

Recommends:   bind-utils
Recommends:   bind-dnssec-utils
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(libcap) >= 2.10
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libnghttp2)
BuildRequires:  pkgconfig(readline)
BuildRequires:  systemd
BuildRequires:  pkgconfig(libuv)
%if %{with DLZ}
BuildRequires:  openldap-devel
BuildRequires:  postgresql-devel
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  mysql-devel
%endif
%if %{with UNITTEST} || %{with SYSTEMTEST}
BuildRequires:  softhsm
BuildRequires:  pkgconfig(cmocka)
%endif
%if %{with SYSTEMTEST}
# bin/tests/system dependencies
BuildRequires:  perl(Net::DNS) perl(Net::DNS::Nameserver) perl(Time::HiRes) perl(Getopt::Long)
# manual configuration requires this tool
BuildRequires:  iproute
%endif
%if %{with GSSTSIG}
BuildRequires:  krb5-devel
%endif
%if %{with LMDB}
BuildRequires:  lmdb-devel
%endif
%if %{with JSON}
BuildRequires:  json-c-devel
%endif
%if %{with GEOIP2}
BuildRequires:  pkgconfig(libmaxminddb)
%endif
# Needed to regenerate dig.1 manpage
%if %{with DOC} || %{with MAN}
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  doxygen
%endif

%description
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named),
which resolves host names to IP addresses; a resolver library
(routines for applications to use when interfacing with DNS); and
tools for verifying that the DNS server is operating properly.

%package utils
Summary: Utilities for querying DNS name servers
Group:      Networking/Other
Conflicts:  bind < 9.11.5.P1-3
Conflicts:  bind-dnssec-utils < 9.11.9
Obsoletes: %{name}-pkcs11-utils < 32:9.18.4-2

%description utils
Bind-utils contains a collection of utilities for querying DNS (Domain
Name System) name servers to find out information about Internet
hosts. These tools will provide you with the IP addresses for given
host names, as well as other information about registered domains and
network addresses.

You should install %{name}-utils if you need to get information from DNS name
servers.

%package dnssec-utils
Summary: DNSSEC keys and zones management utilities
Group:      Networking/Other
Conflicts:  bind-utils < 9.11.5.P1-6
Obsoletes: python3-%{name} < 9.18.0

%description dnssec-utils
%{name}-dnssec-utils contains a collection of utilities for editing
DNSSEC keys and BIND zone files. These tools provide generation,
revocation and verification of keys and DNSSEC signatures in zone files.

You should install %{name}-dnssec-utils if you need to sign a DNS zone
or maintain keys for it.

%package -n %{libname}
Summary: Libraries used by the BIND DNS packages
Group:   System/Libraries

%description -n %{libname}
Contains heavyweight version of BIND suite libraries used by both named DNS
server and utilities in bind-utils package.

%package    devel
Summary:    Include files and libraries needed for bind-dyndb-ldap
Group:      Development/C
Requires:   %{libname} = %{version}-%{release}

%description devel
The %{name}-devel package contains full version of the header files and libraries
required for building bind-dyndb-ldap. Upstream no longer supports nor recommends
bind libraries for third party applications.

%package chroot
Summary:        A chroot runtime environment for the ISC BIND DNS server, named(8)
Prefix:         %{chroot_prefix}
# grep is required due to setup-named-chroot.sh script
Requires:       grep
Requires:       %{name} = %{version}-%{release}

%description chroot
This package contains a tree of files which can be used as a
chroot(2) jail for the named(8) program from the BIND package.
Based on the code from Jan "Yenya" Kasprzak <kas@fi.muni.cz>


%if %{with DLZ}
%package dlz-filesystem
Summary: BIND server filesystem DLZ module
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-filesystem
Dynamic Loadable Zones filesystem module for BIND server.

%package dlz-ldap
Summary: BIND server ldap DLZ module
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-ldap
Dynamic Loadable Zones LDAP module for BIND server.

%package dlz-mysql
Summary: BIND server mysql and mysqldyn DLZ modules
Group:   System/Servers
Requires: bind = %{version}-%{release}

%description dlz-mysql
Dynamic Loadable Zones MySQL module for BIND server.
Contains also mysqldyn module with dynamic DNS updates (DDNS) support.

%package dlz-sqlite3
Summary: BIND server sqlite3 DLZ module
Requires: bind = %{version}-%{release}

%description dlz-sqlite3
Dynamic Loadable Zones sqlite3 module for BIND server.
%endif

%if %{with DOC}
%package doc
Summary:   BIND 9 Administrator Reference Manual
Requires:  python3-sphinx_rtd_theme
BuildArch: noarch

%description doc
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named),
which resolves host names to IP addresses; a resolver library
(routines for applications to use when interfacing with DNS); and
tools for verifying that the DNS server is operating properly.

This package contains BIND 9 Administrator Reference Manual
in HTML and PDF format.
%endif

%prep
%autosetup -n %{name}-%{version} -p1



%build
## We use out of tree configure/build for export libs
%define _configure "../configure"

%serverbuild

CFLAGS="$CFLAGS $RPM_OPT_FLAGS"
export CFLAGS
export STD_CDEFINES="$CPPFLAGS"


sed -i -e \
's/([bind_VERSION_EXTRA],\s*\([^)]*\))/([bind_VERSION_EXTRA], \1-RH)/' \
configure.ac

autoreconf --force --install

mkdir build

%if %{with DLZ}
# DLZ modules do not support oot builds. Copy files into build
mkdir -p build/contrib/dlz
cp -frp contrib/dlz/modules build/contrib/dlz/modules
%endif

pushd build
LIBDIR_SUFFIX=
export LIBDIR_SUFFIX
%configure \
  --localstatedir=%{_var} \
  --with-pic \
  --disable-static \
  --includedir=%{_includedir}/bind9 \
  --with-tuning=large \
  --with-libidn2 \
%if %{with GEOIP2}
  --with-maxminddb \
%endif
%if %{with GSSTSIG}
  --with-gssapi=yes \
%endif
%if %{with LMDB}
  --with-lmdb=yes \
%else
  --with-lmdb=no \
%endif
%if %{with JSON}
  --with-json-c \
%endif
%if %{with UNITTEST}
  --with-cmocka \
%endif
  --enable-fixed-rrset \
  --enable-full-report \
;


%make_build

%if %{with DOC}
  make doc
%endif

%if %{with DLZ}
  pushd contrib/dlz/modules
  for DIR in filesystem ldap mysql mysqldyn sqlite3; do
    make -C $DIR CFLAGS="-fPIC -I../include $CFLAGS $LDFLAGS -DPTHREADS=1" LDFLAGS="$LDFLAGS"
  done
  popd
%endif
	
popd # build

%install

# Build directory hierarchy
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_libdir}/{bind,named}
mkdir -p %{buildroot}%{_localstatedir}/named/{slaves,data,dynamic}
mkdir -p %{buildroot}%{_mandir}/{man1,man5,man8}
mkdir -p %{buildroot}/run/named
mkdir -p %{buildroot}%{_localstatedir}/log

#chroot
for D in %{chroot_create_directories}; do
    mkdir -p %{buildroot}/%{chroot_prefix}${D}
done

# create symlink as it is on real filesystem
pushd %{buildroot}/%{chroot_prefix}/var
ln -s ../run run
popd

# these are required to prevent them being erased during upgrade of previous
touch %{buildroot}/%{chroot_prefix}/etc/named.conf
#end chroot

pushd build
%make_install
popd

# Remove unwanted files
rm -f %{buildroot}/etc/bind.keys

# Systemd unit files
install -d -m 755 %{buildroot}%{_unitdir}
install -m 644 %{SOURCE37} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE38} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE44} %{buildroot}%{_unitdir}
install -m 644 %{SOURCE46} %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_libexecdir}
install -m 755 %{SOURCE41} %{buildroot}%{_libexecdir}/setup-named-chroot.sh
install -m 755 %{SOURCE42} %{buildroot}%{_libexecdir}/generate-rndc-key.sh

install -m 755 %{SOURCE48} %{buildroot}%{_libexecdir}/setup-named-softhsm.sh

install -m 644 %SOURCE3 %{buildroot}/etc/logrotate.d/named
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/named
install -m 644 %{SOURCE49} %{buildroot}%{_sysconfdir}/named-chroot.files

pushd ${RPM_BUILD_ROOT}%{_sbindir}
# Compatibility with previous major versions, only for selected binaries
for BIN in named-checkconf named-checkzone named-compilezone
do
  ln -s ../bin/$BIN $BIN
done
popd

%if %{with DLZ}
  pushd build
  pushd contrib/dlz/modules
  for DIR in filesystem ldap mysql mysqldyn sqlite3; do
    %make_install -C $DIR libdir=%{_libdir}/bind
  done
  pushd %{buildroot}/%{_libdir}/named
    cp -s ../bind/dlz_*.so .
  popd
  mkdir -p doc/{mysql,mysqldyn}
  cp -p mysqldyn/testing/README doc/mysqldyn/README.testing
  cp -p mysqldyn/testing/* doc/mysqldyn
  cp -p mysql/testing/* doc/mysql
  popd
  popd
%endif

# Remove libtool .la files:
find %{buildroot}/%{_libdir} -name '*.la' -exec '/bin/rm' '-f' '{}' ';';

install -d -m 755 %{buildroot}%{_sysconfdir}/rsyslog.d/
cat > %{buildroot}%{_sysconfdir}/rsyslog.d/named.conf <<'EOF'
$AddUnixListenSocket %{chroot_prefix}/dev/log
EOF

# 9.16.4 installs even manual pages for tools not generated
%if %{without DNSTAP}
rm -f %{buildroot}%{_mandir}/man1/dnstap-read.1* || true
%endif
%if %{without LMDB}
rm -f %{buildroot}%{_mandir}/man8/named-nzd2nzf.8* || true
%endif

pushd %{buildroot}%{_mandir}/man8
ln -s ddns-confgen.8.gz tsig-keygen.8.gz
popd
pushd ${RPM_BUILD_ROOT}%{_mandir}/man1
ln -s named-checkzone.1.gz named-compilezone.1.gz
popd

%if %{with DOC}
mkdir -p %{buildroot}%{_pkgdocdir}
cp -a build/doc/arm/_build/html %{buildroot}%{_pkgdocdir}
rm -rf %{buildroot}%{_pkgdocdir}/html/.{buildinfo,doctrees}
# Share static data from original sphinx package
for DIR in %{python3_sitelib}/sphinx_rtd_theme/static/*
do
  BASE=$(basename -- "$DIR")
  BINDTHEMEDIR="%{buildroot}%{_pkgdocdir}/html/_static/$BASE"
  if [ -d "$BINDTHEMEDIR" ]; then
    rm -rf "$BINDTHEMEDIR"
    ln -s "$DIR" "$BINDTHEMEDIR"
  fi
done
%endif

# Ghost config files:
touch %{buildroot}%{_localstatedir}/log/named.log

# configuration files:
install -m 644 %{SOURCE16} %{buildroot}%{_sysconfdir}/named.conf
touch %{buildroot}%{_sysconfdir}/rndc.{key,conf}
install -m 644 %{SOURCE27} %{buildroot}%{_sysconfdir}/named.root.key
install -m 644 %{SOURCE36} %{buildroot}%{_sysconfdir}/trusted-key.key
mkdir %{buildroot}%{_sysconfdir}/named

# data files:
mkdir -p %{buildroot}%{_localstatedir}/named
install -m 644 %{SOURCE17} %{buildroot}%{_localstatedir}/named/named.ca
install -m 644 %{SOURCE18} %{buildroot}%{_localstatedir}/named/named.localhost
install -m 644 %{SOURCE19} %{buildroot}%{_localstatedir}/named/named.loopback
install -m 644 %{SOURCE20} %{buildroot}%{_localstatedir}/named/named.empty
install -m 644 %{SOURCE23} %{buildroot}%{_sysconfdir}/named.rfc1912.zones 

# sample bind configuration files for %%doc:
mkdir -p sample/etc sample/var/named/{data,slaves}
install -m 644 %{SOURCE25} sample/etc/named.conf
# Copy default configuration to %%doc to make it usable from system-config-bind
install -m 644 %{SOURCE16} named.conf.default
install -m 644 %{SOURCE23} sample/etc/named.rfc1912.zones
install -m 644 %{SOURCE18} %{SOURCE19} %{SOURCE20} sample/var/named
install -m 644 %{SOURCE17} sample/var//named/named.ca
for f in my.internal.zone.db slaves/my.slave.internal.zone.db slaves/my.ddns.internal.zone.db my.external.zone.db; do 
  echo '@ in soa localhost. root 1 3H 15M 1W 1D
  ns localhost.' > sample/var/named/$f; 
done
:;

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m 644 %{SOURCE35} %{buildroot}%{_tmpfilesdir}/named.conf

mkdir -p %{buildroot}%{_sysconfdir}/rwtab.d
install -m 644 %{SOURCE43} %{buildroot}%{_sysconfdir}/rwtab.d/named

%triggerun -- bind < 9.11.5.P1-2.mga7   
# stop the service so as to be able to umount old chroot
systemctl condstop named.service

%pre
%_pre_useradd named /var/named /bin/false

%post
%_tmpfilescreate named
%_post_service named

%preun
%_preun_service named

%postun
%_postun_userdel named

%post chroot
%_post_service named-chroot

%preun chroot
%_preun_service named-chroot
%_preun_service named-chroot-setup

%files
# TODO: Move from lib/bind to lib/named, as used by upstream
# FIXME: current build targets filters into %%_libdir/bind again?
%dir %{_libdir}/bind
%{_libdir}/bind/filter*.so
%dir %{_libdir}/named
%config(noreplace) %{_sysconfdir}/sysconfig/named
%config(noreplace) %{_sysconfdir}/named.root.key
%config(noreplace) %{_sysconfdir}/logrotate.d/named
%{_tmpfilesdir}/named.conf
%{_sysconfdir}/rwtab.d/named
%{_unitdir}/named.service
%{_unitdir}/named-setup-rndc.service
%{_bindir}/named-journalprint
%{_bindir}/named-checkconf
%{_bindir}/named-rrchecker
%{_bindir}/mdig
%{_sbindir}/named
%{_sbindir}/rndc*
%{_sbindir}/named-checkconf
%{_libexecdir}/generate-rndc-key.sh
%{_libexecdir}/setup-named-softhsm.sh
%{_mandir}/man1/mdig.1*
%{_mandir}/man1/named-rrchecker.1*
%{_mandir}/man5/named.conf.5*
%{_mandir}/man5/rndc.conf.5*
%{_mandir}/man8/rndc.8*
%{_mandir}/man8/named.8*
%{_mandir}/man1/named-checkconf.1*
%{_mandir}/man8/rndc-confgen.8*
%{_mandir}/man1/named-journalprint.1*
%{_mandir}/man8/filter-*.8*
%doc README.md named.conf.default
%doc sample/

# main configuration
%dir %{_sysconfdir}/named
%config(noreplace) %verify(not link) %{_sysconfdir}/named.conf
%config(noreplace) %verify(not link) %{_sysconfdir}/named.rfc1912.zones
%attr(-,named,named) %dir %{_localstatedir}/named
%attr(-,named,named) %dir %{_localstatedir}/named/slaves
%attr(-,named,named) %dir %{_localstatedir}/named/data
%attr(-,named,named) %dir %{_localstatedir}/named/dynamic
%ghost %{_localstatedir}/log/named.log
%config %verify(not link) %{_localstatedir}/named/named.ca
%config %verify(not link) %{_localstatedir}/named/named.localhost
%config %verify(not link) %{_localstatedir}/named/named.loopback
%config %verify(not link) %{_localstatedir}/named/named.empty
%ghost %config(noreplace) %{_sysconfdir}/rndc.key
# ^- rndc.key now created on first install only if it does not exist
%ghost %config(noreplace) %{_sysconfdir}/rndc.conf
# ^- The default rndc.conf which uses rndc.key is in named's default internal config -
#    so rndc.conf is not necessary.

%files -n %{libname}
%{_libdir}/libdns-%{version}.so
%{_libdir}/libirs-%{version}.so
%{_libdir}/libisc-%{version}.so
%{_libdir}/libbind9-%{version}.so
%{_libdir}/libns-%{version}.so
%{_libdir}/libisccc-%{version}.so
%{_libdir}/libisccfg-%{version}.so


%files utils
%{_bindir}/dig
%{_bindir}/delv
%{_bindir}/host
%{_bindir}/nslookup
%{_bindir}/nsupdate
%{_bindir}/arpaname
%{_sbindir}/ddns-confgen
%{_sbindir}/tsig-keygen
%{_bindir}/nsec3hash
%{_bindir}/named-checkzone
%{_bindir}/named-compilezone
%{_sbindir}/named-checkzone
%{_sbindir}/named-compilezone
%if %{with DNSTAP}
%{_bindir}/dnstap-read
%{_mandir}/man1/dnstap-read.1*
%endif
%if %{with LMDB}
%{_bindir}/named-nzd2nzf
%{_mandir}/man1/named-nzd2nzf.1*
%endif
%{_mandir}/man1/host.1*
%{_mandir}/man1/nsupdate.1*
%{_mandir}/man1/dig.1*
%{_mandir}/man1/delv.1*
%{_mandir}/man1/nslookup.1*
%{_mandir}/man1/arpaname.1*
%{_mandir}/man8/ddns-confgen.8*
%{_mandir}/man8/tsig-keygen.8*
%{_mandir}/man1/nsec3hash.1*
%{_mandir}/man1/named-checkzone.1*
%{_mandir}/man1/named-compilezone.1*
%{_sysconfdir}/trusted-key.key

%files dnssec-utils
%{_bindir}/dnssec*
%{_mandir}/man1/dnssec*.1*

%files devel
%{_libdir}/libbind9.so
%{_libdir}/libisccc.so
%{_libdir}/libns.so
%{_libdir}/libdns.so
%{_libdir}/libirs.so
%{_libdir}/libisc.so
%{_libdir}/libisccfg.so
%dir %{_includedir}/bind9
%{_includedir}/bind9/bind9
%{_includedir}/bind9/isccc
%{_includedir}/bind9/ns
%{_includedir}/bind9/dns
%{_includedir}/bind9/dst
%{_includedir}/bind9/irs
%{_includedir}/bind9/isc
%{_includedir}/bind9/isccfg

%files chroot
%config(noreplace) %{_sysconfdir}/rsyslog.d/named.conf
%config(noreplace) %{_sysconfdir}/named-chroot.files
%{_unitdir}/named-chroot.service
%{_unitdir}/named-chroot-setup.service
%{_libexecdir}/setup-named-chroot.sh
%defattr(0664,root,named,-)
%ghost %dev(c,1,3) %verify(not mtime) %{chroot_prefix}/dev/null
%ghost %dev(c,1,8) %verify(not mtime) %{chroot_prefix}/dev/random
%ghost %dev(c,1,9) %verify(not mtime) %{chroot_prefix}/dev/urandom
%ghost %dev(c,1,5) %verify(not mtime) %{chroot_prefix}/dev/zero
%defattr(0644,root,named,0755)
%dir %{chroot_prefix}
%dir %{chroot_prefix}/dev
%dir %{chroot_prefix}%{_sysconfdir}
%dir %{chroot_prefix}%{_sysconfdir}/named
%dir %{chroot_prefix}%{_sysconfdir}/pki
%dir %{chroot_prefix}%{_sysconfdir}/pki/dnssec-keys
%dir %{chroot_prefix}%{_sysconfdir}/crypto-policies
%dir %{chroot_prefix}%{_sysconfdir}/crypto-policies/back-ends
%dir %{chroot_prefix}%{_localstatedir}
%dir %{chroot_prefix}/run
%ghost %config(noreplace) %{chroot_prefix}%{_sysconfdir}/named.conf
%defattr(-,root,root,-)
%dir %{chroot_prefix}/usr
%dir %{chroot_prefix}/%{_libdir}
%dir %{chroot_prefix}/%{_libdir}/bind
%dir %{chroot_prefix}/%{_datadir}/GeoIP
%defattr(0664,root,named,01775)
%dir %{chroot_prefix}%{_localstatedir}/named
%defattr(0664,named,named,0775)
%dir %{chroot_prefix}%{_localstatedir}/tmp
%dir %{chroot_prefix}%{_localstatedir}/log
%defattr(-,named,named,-)
%dir %{chroot_prefix}/run/named
%{chroot_prefix}%{_localstatedir}/run

%if %{with DLZ}
%files dlz-filesystem
%{_libdir}/{named,bind}/dlz_filesystem_dynamic.so

%files dlz-mysql
%{_libdir}/{named,bind}/dlz_mysql_dynamic.so
%doc build/contrib/dlz/modules/doc/mysql
%{_libdir}/{named,bind}/dlz_mysqldyn_mod.so
%doc build/contrib/dlz/modules/doc/mysqldyn

%files dlz-ldap
%{_libdir}/{named,bind}/dlz_ldap_dynamic.so
%doc contrib/dlz/modules/ldap/testing/*

%files dlz-sqlite3
%{_libdir}/{named,bind}/dlz_sqlite3_dynamic.so
%doc contrib/dlz/modules/sqlite3/testing/*

%endif

%if %{with DOC}
%files doc
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/html
%doc %{_pkgdocdir}/Bv9ARM.html
%endif


%changelog
* Fri Jan 31 2025 ns80 <ns80> 9.18.33-1.mga10
+ Revision: 2143880
- disable DLZ
- new version 9.18.33 for CVE-2024-11187 and CVE-2024-12705 (mga#33972)

* Thu Oct 17 2024 mrambo3501 <mrambo3501> 9.18.30-1.mga10
+ Revision: 2107822
- verison 9.18.30

* Sun Aug 25 2024 neoclust <neoclust> 9.18.28-1.mga10
+ Revision: 2091160
- New version 9.18.28

* Wed Feb 14 2024 ns80 <ns80> 9.18.24-1.mga10
+ Revision: 2041098
- new version 9.18.24 for CVE-2023-4408, CVE-2023-5517, CVE-2023-5679, CVE-2023-50387, CVE-2023-50868 (mga#32846)

* Tue Sep 26 2023 ns80 <ns80> 9.18.19-1.mga10
+ Revision: 1991069
- new version 9.18.19 for CVE-2023-3341 (mga#32039)

* Sun Jul 02 2023 guillomovitch <guillomovitch> 9.18.16-1.mga9
+ Revision: 1963485
- new version 9.8.16

* Tue Jun 27 2023 neoclust <neoclust> 9.18.15-2.mga9
+ Revision: 1963170
- Add patch100/101: Fixes CVE-2023-2828 CVE-2023-2911 (mga#32039)

* Mon May 22 2023 guillomovitch <guillomovitch> 9.18.15-1.mga9
+ Revision: 1957770
- new version 9.8.15

* Fri Apr 21 2023 luigiwalser <luigiwalser> 9.18.14-1.mga9
+ Revision: 1953740
- 9.18.14
- 9.18.13
- remove patch 22 (upstreamed)

* Thu Feb 16 2023 luigiwalser <luigiwalser> 9.18.12-1.mga9
+ Revision: 1943534
- 9.18.12

* Wed Jan 25 2023 luigiwalser <luigiwalser> 9.18.11-1.mga9
+ Revision: 1936059
- 9.18.11
- rediff patch 22

* Wed Dec 21 2022 luigiwalser <luigiwalser> 9.18.10-1.mga9
+ Revision: 1925611
- 9.18.10

* Sat Dec 17 2022 guillomovitch <guillomovitch> 9.18.9-2.mga9
+ Revision: 1924300
- fix RDNC key generation (mga #31264)

* Wed Nov 16 2022 luigiwalser <luigiwalser> 9.18.9-1.mga9
+ Revision: 1908058
- 9.18.9

* Wed Oct 19 2022 luigiwalser <luigiwalser> 9.18.8-1.mga9
+ Revision: 1897662
- 9.18.8

* Wed Sep 21 2022 luigiwalser <luigiwalser> 9.18.7-1.mga9
+ Revision: 1891246
- 9.18.7
- update patch22 from fedora

* Mon Aug 29 2022 luigiwalser <luigiwalser> 9.18.6-1.mga9
+ Revision: 1881564
- 9.18.6

* Sat Aug 27 2022 guillomovitch <guillomovitch> 9.18.5-1.mga9
+ Revision: 1881043
- new version 9.18.5

* Wed Aug 17 2022 luigiwalser <luigiwalser> 9.16.32-1.mga9
+ Revision: 1878379
- 9.16.32

* Thu Jul 21 2022 luigiwalser <luigiwalser> 9.16.31-1.mga9
+ Revision: 1869780
- 9.16.31

* Thu Jun 16 2022 luigiwalser <luigiwalser> 9.16.30-1.mga9
+ Revision: 1864612
- 9.16.30

* Thu Jun 02 2022 luigiwalser <luigiwalser> 9.16.29-1.mga9
+ Revision: 1861055
- 9.16.29
- renumber patches to match fedora
- add four more patches from fedora

* Mon Apr 25 2022 luigiwalser <luigiwalser> 9.16.28-1.mga9
+ Revision: 1853654
- 9.16.28

* Fri Mar 18 2022 ns80 <ns80> 9.16.27-1.mga9
+ Revision: 1797975
- new version 9.16.27 for CVE-2021-25220 and CVE-2022-0396 (mga#30184)

* Mon Feb 21 2022 tv <tv> 9.16.25-2.mga9
+ Revision: 1782173
- Rebuild for python-3.10

* Thu Jan 20 2022 luigiwalser <luigiwalser> 9.16.25-1.mga9
+ Revision: 1769282
- fix upstream error in contrib/dlz
- 9.16.25

* Thu Dec 16 2021 luigiwalser <luigiwalser> 9.16.24-1.mga9
+ Revision: 1762243
- 9.16.24
- rediffed patch 157 from fedora

* Thu Nov 25 2021 luigiwalser <luigiwalser> 9.16.23-1.mga9
+ Revision: 1759139
- 9.16.23

* Sun Oct 31 2021 guillomovitch <guillomovitch> 9.16.22-1.mga9
+ Revision: 1753500
- new version 9.16.22

* Sat Oct 02 2021 wally <wally> 9.16.21-2.mga9
+ Revision: 1747628
- rebuild for openssl 3.0.0

* Sat Sep 25 2021 guillomovitch <guillomovitch> 9.16.21-1.mga9
+ Revision: 1746374
- new version 9.16.21

* Thu Aug 19 2021 luigiwalser <luigiwalser> 9.16.20-1.mga9
+ Revision: 1741937
- 9.16.20 (fixes CVE-2021-25218)

* Tue Aug 03 2021 luigiwalser <luigiwalser> 9.16.19-1.mga9
+ Revision: 1738833
- 9.16.19

* Wed Jul 14 2021 guillomovitch <guillomovitch> 9.16.18-1.mga9
+ Revision: 1736001
- new version 9.16.18

* Sat May 01 2021 guillomovitch <guillomovitch> 9.16.15-1.mga9
+ Revision: 1720716
- new version 9.16.15

* Sun Mar 28 2021 guillomovitch <guillomovitch> 9.16.13-1.mga9
+ Revision: 1711503
- new version 9.16.13
- ship all libs in a single package, as they all share same soname now

* Fri Mar 26 2021 ovitters <ovitters> 9.16.11-3.mga9
+ Revision: 1710487
- rebuild for Python 3.9

* Fri Mar 26 2021 tv <tv> 9.16.11-2.mga9
+ Revision: 1710471
- rebuild for python 3.9

* Fri Feb 26 2021 guillomovitch <guillomovitch> 9.16.11-1.mga9
+ Revision: 1691498
- update to version 9.16.11

* Sat Jan 23 2021 luigiwalser <luigiwalser> 9.11.27-1.mga8
+ Revision: 1673030
- 9.11.27
- update patches 133 and 177 from fedora
- fix docbook build issues (from fedora)
- 9.11.26

* Wed Dec 16 2020 luigiwalser <luigiwalser> 9.11.25-1.mga8
+ Revision: 1657940
- 9.11.25

* Mon Nov 30 2020 luigiwalser <luigiwalser> 9.11.24-2.mga8
+ Revision: 1650724
- rebuild for json-c

* Sat Oct 24 2020 guillomovitch <guillomovitch> 9.11.24-1.mga8
+ Revision: 1639041
- new version 9.11.24

* Mon Sep 21 2020 luigiwalser <luigiwalser> 9.11.23-1.mga8
+ Revision: 1629346
- 9.11.23
- add patches from fedora that fix build on non-Intel arches

* Sat Aug 22 2020 guillomovitch <guillomovitch> 9.11.22-1.mga8
+ Revision: 1617916
- new version 9.11.22

* Wed Aug 05 2020 luigiwalser <luigiwalser> 9.11.21-1.mga8
+ Revision: 1611218
- 9.11.21

* Sat Jun 20 2020 guillomovitch <guillomovitch> 9.11.20-1.mga8
+ Revision: 1598102
- new version 9.11.20

* Thu May 28 2020 guillomovitch <guillomovitch> 9.11.19-2.mga8
+ Revision: 1588691
- new version 9.11.19
- do not ship obsolete named-bootconf utility
- move back non-dnssec-related tools to bind-utils subpackage
- add GeoIP files in chroot

* Thu Apr 16 2020 luigiwalser <luigiwalser> 9.11.18-1.mga8
+ Revision: 1567796
- 9.11.18
- rediff patches 149 and 171

* Thu Apr 09 2020 luigiwalser <luigiwalser> 9.11.17-1.mga8
+ Revision: 1565926
- 9.11.17
- renumber patch 17 to 13
- rediffed patches 12, 13, 158, 159, 177 from fedora
- one local adjustment to patch 12

* Wed Feb 19 2020 umeabot <umeabot> 9.11.14-2.mga8
+ Revision: 1543192
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 guillomovitch <guillomovitch> 9.11.14-1.mga8
+ Revision: 1481467
- new version 9.11.14
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 26 2019 guillomovitch <guillomovitch> 9.11.13-1.mga8
+ Revision: 1463000
- sync service files with fedora
- drop dns-keygen utility, obsoleted by rndc-confgen -a
- sync with fedora spec
- new version 9.11.13
+ zezinho <zezinho>
- new security fix version mga#25724

* Sun Nov 17 2019 guillomovitch <guillomovitch> 9.11.12-2.mga8
+ Revision: 1461579
- new version 9.11.12

* Wed Sep 11 2019 tv <tv> 9.11.9-2.mga8
+ Revision: 1439639
- rebuild for python-3.8

* Sun Aug 18 2019 guillomovitch <guillomovitch> 9.11.9-1.mga8
+ Revision: 1429763
- limit conditional build options to invasive options only (sdb, pkcs11)
- add JSON support
- drop deprecated geoip support, switch to geolite instead
- more dependencies from devel packages
- new version 9.11.9
- sync patches with Fedora
- add native-enabled PKCSS#11 version, from Fedora

* Mon Jul 08 2019 guillomovitch <guillomovitch> 9.11.8-2.mga8
+ Revision: 1419411
- add proper conflict tags to allow update
- update rfc1912.zones and root.key files
- don't forget to ship root.key file

* Thu Jul 04 2019 guillomovitch <guillomovitch> 9.11.8-1.mga8
+ Revision: 1418613
- new version 9.11.8
- sync patches with Fedora

* Mon Apr 22 2019 guillomovitch <guillomovitch> 9.11.6-1.mga7
+ Revision: 1394839
- new version 9.11.6

* Sat Mar 02 2019 guillomovitch <guillomovitch> 9.11.5.P4-1.mga7
+ Revision: 1371040
- new version 9.11.5-P4
- replace hard dependency on bind-utils to soft dependencies
  on bind-utils and bind-dnssec-utils

* Wed Feb 13 2019 luigiwalser <luigiwalser> 9.11.5.P1-7.mga7
+ Revision: 1366523
- rebuild for libidn2

* Wed Jan 30 2019 guillomovitch <guillomovitch> 9.11.5.P1-6.mga7
+ Revision: 1361975
- fix multiple issues reported in bug #2412:
- drop named.root.key file
- update root zone file
- make /var/named owned by named.named
  split dnssec-related tools in bind-dnssec-utils

* Wed Jan 09 2019 wally <wally> 9.11.5.P1-5.mga7
+ Revision: 1353594
- rebuild for new libidn2

* Sun Jan 06 2019 kekepower <kekepower> 9.11.5.P1-4.mga7
+ Revision: 1350232
- Rebuild for Python 3.7

* Tue Jan 01 2019 guillomovitch <guillomovitch> 9.11.5.P1-3.mga7
+ Revision: 1348140
- better package name for libbind9
- split shared libraries in subpackages
- sync with fedora setup:
 - use /var/named/chroot and /var/named/chroot_sdb as chroot roots
 - ship chroot files and systemd units in distinct subpackages
 - use fedora setup-named-chroot script

* Sat Dec 15 2018 luigiwalser <luigiwalser> 9.11.5.P1-1.mga7
+ Revision: 1341513
- 9.11.5-P1
- rediff patches 12, 74, 102, 106, and 154

* Fri Sep 21 2018 umeabot <umeabot> 9.11.4.P1-3.mga7
+ Revision: 1295420
- Mageia 7 Mass Rebuild

* Tue Aug 28 2018 guillomovitch <guillomovitch> 9.11.4.P1-2.mga7
+ Revision: 1255332
- update root zone and root zone key (#23489)

* Sun Aug 12 2018 guillomovitch <guillomovitch> 9.11.4.P1-1.mga7
+ Revision: 1251146
- new version 9.11.4-P1
- sync patch set with Fedora

* Thu Jul 05 2018 guillomovitch <guillomovitch> 9.11.3-3.mga7
+ Revision: 1242016
- fix CVE-2018-5738

* Fri May 11 2018 kekepower <kekepower> 9.11.3-2.mga7
+ Revision: 1228347
- Rebuild for libidn 1.35

* Thu Mar 15 2018 luigiwalser <luigiwalser> 9.11.3-1.mga7
+ Revision: 1209780
- query-loc is no more
- 9.11.3 (fixes security issue with type lists)
- rediff patches 12, 72, 119
- remove patches 142 and 143 (fixed upstream)

* Thu Jan 18 2018 guillomovitch <guillomovitch> 9.11.2.P1-1.mga7
+ Revision: 1194462
- new version 9.11.2-P1

* Thu Dec 21 2017 guillomovitch <guillomovitch> 9.11.2-3.mga7
+ Revision: 1183674
- rebuild to fix mariadb dependency

* Mon Aug 21 2017 guillomovitch <guillomovitch> 9.11.2-2.mga7
+ Revision: 1142608
- enable DNSSEC by default (mga#20872)

* Sun Aug 20 2017 guillomovitch <guillomovitch> 9.11.2-1.mga7
+ Revision: 1142475
- new version 9.11.2
- support for system-wide crypto policies
- misc packaging fixes

* Sat Jul 01 2017 luigiwalser <luigiwalser> 9.10.5.P2-1.mga6
+ Revision: 1108884
- 9.10.5-P2 (fixes CVE-2017-3142 and CVE-2017-3143)

* Fri May 26 2017 guillomovitch <guillomovitch> 9.10.5-2.mga6
+ Revision: 1104787
- ensure /dev/urandom is present in chroot (#12425)

* Thu Apr 20 2017 luigiwalser <luigiwalser> 9.10.5-1.mga6
+ Revision: 1096912
- add python-bind subpackage
- 9.10.5
- rediff patches 12, 17, 73, 83, 102, 104, 109

* Fri Apr 14 2017 luigiwalser <luigiwalser> 9.10.4.P8-1.mga6
+ Revision: 1096543
- 9.10.4-P8 (fixes CVE-2017-313[6-8])

* Sun Feb 12 2017 luigiwalser <luigiwalser> 9.10.4.P6-1.mga6
+ Revision: 1085789
- 9.10.4-P6 (fixes CVE-2017-3135)

* Thu Jan 12 2017 luigiwalser <luigiwalser> 9.10.4.P5-1.mga6
+ Revision: 1081155
- 9.10.4-P5 (fixes CVE-2016-9131, CVE-2016-9147, CVE-2016-9444, CVE-2016-9778)

* Tue Nov 01 2016 luigiwalser <luigiwalser> 9.10.4.P4-1.mga6
+ Revision: 1064711
- 9.10.4-P4 (fixes CVE-2016-8864)

* Tue Sep 27 2016 luigiwalser <luigiwalser> 9.10.4.P3-1.mga6
+ Revision: 1057171
- 9.10.4-P3 (fixes CVE-2016-2776)

* Sun Aug 21 2016 guillomovitch <guillomovitch> 9.10.4.P2-3.mga6
+ Revision: 1047608
- split systemd services to handle chroot separatly

* Thu Jul 21 2016 guillomovitch <guillomovitch> 9.10.4.P2-2.mga6
+ Revision: 1043009
- fix conflict on documentation files between subpackages (#10880)

* Tue Jul 19 2016 luigiwalser <luigiwalser> 9.10.4.P2-1.mga6
+ Revision: 1042539
- 9.10.4-P2 (fixes CVE-2016-2775)

* Thu Jun 02 2016 luigiwalser <luigiwalser> 9.10.4.P1-1.mga6
+ Revision: 1020040
- remove spurious variable from Source35
- add patch13 reverting upstream change to use non-existent strlcat function
- 9.10.4-P1
- removed upstreamed patch 209
- rediff patches 87, 104, 109, 133, 135, 11, 17

* Wed Mar 09 2016 luigiwalser <luigiwalser> 9.10.3.P4-1.mga6
+ Revision: 988664
- 9.10.3-P4 (fixes CVE-2016-1285, CVE-2016-1286, CVE-2016-2088)

* Sun Feb 28 2016 oden <oden> 9.10.3.P3-2.mga6
+ Revision: 980334
- rebuilt for postgresql 9.5.x

* Wed Jan 20 2016 luigiwalser <luigiwalser> 9.10.3.P3-1.mga6
+ Revision: 925991
- 9.10.3-P3 (fixes CVE-2015-8704 and CVE-2015-8705)

* Sat Dec 19 2015 oden <oden> 9.10.3.P2-2.mga6
+ Revision: 912111
- rebuild
- enable build against libressl
- drop one redundant patch
- drop the broken make check stuff
- drop the gepip patch: https://kb.isc.org/article/AA-01149/0/Using-the-GeoIP-Features-in-BIND-9.10.html
- new named.cache file

* Wed Dec 16 2015 luigiwalser <luigiwalser> 9.10.3.P2-1.mga6
+ Revision: 910840
- 9.10.3-P2 (fixes CVE-2015-8000 and CVE-2015-8461)
- update patches 104 and 131 from fedora
- rediff patch 12
- use network-online target dep so it does not try to start too early

* Thu Sep 03 2015 luigiwalser <luigiwalser> 9.10.2.P4-1.mga6
+ Revision: 872459
- 9.10.2-P4 (fixes CVE-2015-5722 and CVE-2015-5986)

* Wed Jul 29 2015 luigiwalser <luigiwalser> 9.10.2.P3-1.mga6
+ Revision: 858920
- 9.10.2-P3 (fixes CVE-2015-5477)

* Wed Jul 08 2015 luigiwalser <luigiwalser> 9.10.2.P2-1.mga6
+ Revision: 852813
- 9.10.2-P2 (fixes CVE-2015-4620)

* Thu Feb 26 2015 colin <colin> 9.10.1.P2-2.mga5
+ Revision: 817024
- Drop Fedora patch rejected by upstream and now dropped from Fedora (which causes crashes rhbz#1172935)

* Thu Feb 19 2015 oden <oden> 9.10.1.P2-1.mga5
+ Revision: 815795
- 9.10.1-P2 (fixes CVE-2015-1349)

* Sat Jan 03 2015 alien <alien> 9.10.1.P1-2.mga5
+ Revision: 808287
- fix mounting /etc/named
- allow mounting rw files
- allow adding custom mounts

* Tue Dec 09 2014 luigiwalser <luigiwalser> 9.10.1.P1-1.mga5
+ Revision: 802431
- 9.10.1-P1 (fixes CVE-2014-8500 and CVE-2014-8680)

* Tue Nov 25 2014 cjw <cjw> 9.10.1-2.mga5
+ Revision: 798994
- rebuild against postgresql9.4

* Tue Sep 23 2014 luigiwalser <luigiwalser> 9.10.1-1.mga5
+ Revision: 721699
- 9.10.1
- add line to patch 72 to fix autoheader complaint
- rediff patch 12 and patch 104
- drop patch 5 (fixed upstream)
- drop patch 125 (seems to not be needed)

* Tue Sep 16 2014 umeabot <umeabot> 9.10.0.P2-2.mga5
+ Revision: 678151
- Mageia 5 Mass Rebuild

* Thu Jun 12 2014 oden <oden> 9.10.0.P2-1.mga5
+ Revision: 635753
- 9.10.0-P2 (fixes CVE-2014-3859, CVE-2014-3214)

* Thu Jun 05 2014 oden <oden> 9.10.0.P1-2.mga5
+ Revision: 633352
- use "-fno-delete-null-pointer-checks" (https://kb.isc.org/article/AA-01167)

* Fri May 09 2014 oden <oden> 9.10.0.P1-1.mga5
+ Revision: 621433
- 9.10.0-P1
- rediff patches
- new named.cache

* Sun Feb 02 2014 oden <oden> 9.9.5-1.mga5
+ Revision: 568669
- 9.9.5
- rediffed most patches

* Mon Jan 13 2014 oden <oden> 9.9.4.P2-1.mga4
+ Revision: 566486
- 9.9.4-P2 (fixes CVE-2014-0591)

* Sat Oct 19 2013 umeabot <umeabot> 9.9.4-2.mga4
+ Revision: 535211
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 oden <oden> 9.9.4-1.mga4
+ Revision: 481658
- the test suite does not work correctly, disable that for now
- 9.9.4
- rediff and drop some patches
- rebuild
- P209: make the test suite work
- more deps
- run the test suite

* Sun Jul 28 2013 oden <oden> 9.9.3.P2-1.mga4
+ Revision: 459394
- 9.9.3-P2 (fixes CVE-2013-4854)

* Wed Jun 05 2013 oden <oden> 9.9.3.P1-1.mga4
+ Revision: 437452
- 9.9.3-P1 (fixes CVE-2013-3919 introduced with 9.9.3)

* Wed May 29 2013 oden <oden> 9.9.3-1.mga4
+ Revision: 431338
- 9.9.3
- slight sync with bind-9.9.3-0.7.rc2.fc20.src.rpm
- rediffed some patches

* Wed May 08 2013 luigiwalser <luigiwalser> 9.9.2.P2-2.mga3
+ Revision: 412751
- fix issues caused by leftover files in the chroot when upgrading (mga#10025)

* Mon Apr 01 2013 luigiwalser <luigiwalser> 9.9.2.P2-1.mga3
+ Revision: 406905
- 9.9.2-P2 (fixes CVE-2013-2266)
- add patch from redhat to fix CVE-2012-5689

* Sun Mar 24 2013 colin <colin> 9.9.2.P1-6.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Tue Feb 26 2013 neoclust <neoclust> 9.9.2.P1-5.mga3
+ Revision: 400410
- Make sure named-sdb wait for ldap to be started

* Wed Feb 13 2013 dlucio <dlucio> 9.9.2.P1-4.mga3
+ Revision: 398286
- for new openssl

* Fri Jan 11 2013 umeabot <umeabot> 9.9.2.P1-3.mga3
+ Revision: 346903
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 08 2012 guillomovitch <guillomovitch> 9.9.2.P1-2.mga3
+ Revision: 328904
- rework chroot setup script for clarity, and mount everything possible as read-only (oden suggestion)
- disable dnssec by default (oden suggestion)

* Wed Dec 05 2012 oden <oden> 9.9.2.P1-1.mga3
+ Revision: 326885
- 9.9.2-P1 (fixes CVE-2012-5688)

* Tue Dec 04 2012 guillomovitch <guillomovitch> 9.9.2-5.mga3
+ Revision: 326686
- switch to a versioned post-uninstallation trigger to handle upgrade, so as to
  keep modified configuration files
- use arch-specific directories list in chroot creation script

* Sun Nov 25 2012 colin <colin> 9.9.2-4.mga3
+ Revision: 321818
- Fix up tmpfiles config

* Sat Nov 17 2012 guillomovitch <guillomovitch> 9.9.2-3.mga3
+ Revision: 319149
- don't ship rndc.conf, the internal default configuration is to use rndc.key
- migrate the remaning parts of previous default configuration back to /etc before update (fix #8095)
- migrate zone files from chroot before update, as they are now bind-mounted
  from the non-chroot location
- keep rfc1912 zones in main configuration file, for closer similarity with previous setup

* Mon Nov 12 2012 guillomovitch <guillomovitch> 9.9.2-2.mga3
+ Revision: 317273
- document SDB support in README.mga
- add %%{_libdir}/openssl in chroot (fix #8029)
- fix pid file path in systemd service

* Fri Nov 09 2012 guillomovitch <guillomovitch> 9.9.2-1.mga3
+ Revision: 316758
- sync with fedora spec, for easier maintainance:
  the real files now live outside the chroot
- new version
+ fwang <fwang>
- update rpm group

* Wed Oct 10 2012 fwang <fwang> 9.9.1.P4-1.mga3
+ Revision: 304065
- new version 9.9.1-p4
+ guillomovitch <guillomovitch>
- install tmpfiles configuration under %%_prefix/lib
- don't ship /var/run directory

* Thu Sep 13 2012 oden <oden> 9.9.1.P3-1.mga3
+ Revision: 293449
- 9.9.1-P3 (fixes CVE-2012-4244)

* Mon Jul 30 2012 guillomovitch <guillomovitch> 9.9.1.P2-1.mga3
+ Revision: 276006
- new version

* Tue Jun 05 2012 guillomovitch <guillomovitch> 9.9.1.P1-1.mga3
+ Revision: 256011
- new version
- update patchset from fedora

* Sat Apr 28 2012 tmb <tmb> 9.9.0-7.mga2
+ Revision: 233607
- Require rpm-helper >= 0.24.8-1 for systemd support

* Fri Apr 27 2012 tmb <tmb> 9.9.0-6.mga2
+ Revision: 233504
- rebuild for versioned rpm-helper requires

* Mon Mar 12 2012 guillomovitch <guillomovitch> 9.9.0-5.mga2
+ Revision: 223162
- test device file existence before checking its minor number

* Sat Mar 10 2012 guillomovitch <guillomovitch> 9.9.0-4.mga2
+ Revision: 222546
- fix non-writable directory (#4147)
- don't use syslogadd macro, but manage rsyslog file directly, to
  use default daemon log facility destination
- fix openssl libs setup in chroot
- add a default syslog channel
- remove wrong device file in chroot in post-install (#3028)

* Thu Mar 08 2012 guillomovitch <guillomovitch> 9.9.0-3.mga2
+ Revision: 221653
- use %%_post_syslogadd and %%_preun_syslogdel macros
- fix urandom device minor number (#3028)
- fixed pid file path

* Wed Mar 07 2012 guillomovitch <guillomovitch> 9.9.0-2.mga2
+ Revision: 221261
- extract chroot creation logic in an external script, to be shared
  between sysinit initscript and systemd service
- don't ship services both for chrooted and non-chrooted setup, mageia
  package only support chroot installation currently
- fix systemd services, we don't use the same root for chroot as fedora
- drop old chroot migration pre-installation code

* Tue Mar 06 2012 guillomovitch <guillomovitch> 9.9.0-1.mga2
+ Revision: 220366
- new version
- systemd integration

* Sat Jan 28 2012 anssi <anssi> 9.8.1P1-2.mga2
+ Revision: 202727
- add a managed-keys-directory /var/named/dynamic in the chroot (see
  bug #3379 for discussion)
+ fwang <fwang>
- convert doc into noarch package

* Fri Dec 09 2011 guillomovitch <guillomovitch> 9.8.1P1-1.mga2
+ Revision: 179488
- new version

* Wed Sep 14 2011 guillomovitch <guillomovitch> 9.8.1-1.mga2
+ Revision: 143347
- drop old README.urpmi file
- new version
- sync SDB patches and sources with fedora
- sanitize doc installation

* Tue Aug 30 2011 guillomovitch <guillomovitch> 9.8.0P4-1.mga2
+ Revision: 136692
- disable parallel build again, it fails with too many CPUs
- more spec cleanup
- use version tag only for upstream versioning, not release tag
- update dyndb patch
- drop ppc patch
- renumerate patches to match fedora ones
- new version
- allow parallel build (fedora patch)
- no need to build a non-threaded host binary, the threaded version works correctly

* Mon Aug 29 2011 guillomovitch <guillomovitch> 9.8.0-7.P1.mga2
+ Revision: 136264
- spec cleanup
- ensure missing headers, such as dns/client.h, are present

* Fri May 06 2011 pterjan <pterjan> 9.8.0-6.P1.mga1
+ Revision: 95476
- Update to 9.8.0-P1 (CVE-2011-1907)

* Sun May 01 2011 cjw <cjw> 9.8.0-5.mga1
+ Revision: 94107
- get libgost.so fix working on i586 as well by using %%_target_cpu instead of %%_build_arch

* Sat Apr 30 2011 cjw <cjw> 9.8.0-4.mga1
+ Revision: 93654
- copy only the libgost.so module for the bind build architecture to the chroot (improved fix for bug #871)

* Tue Apr 19 2011 misc <misc> 9.8.0-3.mga1
+ Revision: 88257
- fix the initscript, as proposed by Dave Hodgins

* Mon Apr 18 2011 misc <misc> 9.8.0-2.mga1
+ Revision: 87629
- copy libgost.so in the chroot, fix bug #871

* Sun Apr 17 2011 misc <misc> 9.8.0-1.mga1
+ Revision: 87096
- update to 9.8.0, update dyndb patch from fedora
- remove old Obsoletes/Provides ( date back to mandrake days )
- remove old script to cope with old packages migration
- remove old trigger

* Thu Mar 24 2011 dmorgan <dmorgan> 9.7.3-2.mga1
+ Revision: 76740
- Rebuild against new mysql

* Sat Mar 05 2011 mikala <mikala> 9.7.3-1.mga1
+ Revision: 64748
- Update to bind version 9.7.3 ( fix CVE-2011-0414 )

* Mon Jan 24 2011 ennael <ennael> 9.7.2-7.mga1
+ Revision: 36775
- remove mdkversion
- imported package bind


* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-7mdv2011.0
+ Revision: 627297
- don't force the usage of automake1.7

* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-6mdv2011.0
+ Revision: 626993
- rebuilt against mysql-5.5.8 libs, again

* Mon Dec 27 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-5mdv2011.0
+ Revision: 625415
- rebuilt against mysql-5.5.8 libs

* Thu Dec 09 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-4mdv2011.0
+ Revision: 618160
- 9.7.2-P3

* Fri Oct 01 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-3mdv2011.0
+ Revision: 582292
- 9.7.2-P2

  + Maarten Vanraes <alien@mandriva.org>
    - Add IPv6 filtering support

* Tue Sep 14 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.2-1mdv2011.0
+ Revision: 578198
- 9.7.2

* Thu Jul 15 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.1-1mdv2011.0
+ Revision: 553765
- 9.7.1-P2

* Thu May 20 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.0-5mdv2010.1
+ Revision: 545467
- 9.7.0-P2

* Tue Apr 06 2010 Funda Wang <fwang@mandriva.org> 9.7.0-4mdv2010.1
+ Revision: 531955
- rebuild for new openssl

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.0-3mdv2010.1
+ Revision: 523437
- 9.7.0-P1

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.0-2mdv2010.1
+ Revision: 511553
- rebuilt against openssl-0.9.8m

* Wed Feb 17 2010 Oden Eriksson <oeriksson@mandriva.com> 9.7.0-1mdv2010.1
+ Revision: 507199
- 9.7.0
- drop some redundant patches
- sync some patches with fedora
- drop the missing-dnssec-tools stuff, it's dead

* Wed Feb 17 2010 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-7mdv2010.1
+ Revision: 507019
- rebuild

* Tue Jan 19 2010 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-6mdv2010.1
+ Revision: 493774
- 9.6.1-P3

* Tue Nov 24 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-5mdv2010.1
+ Revision: 469687
- 9.6.1-P2

* Wed Aug 19 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-4mdv2010.0
+ Revision: 418249
- comment the now disabled bogon stuff (duh!)

* Fri Jul 31 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-3mdv2010.0
+ Revision: 405097
- disable the static bogon_acl.conf file as it's too much work
  maintaining it, instead look at http://www.team-cymru.org/Services/Bogons/
- new named.cache file from internic

* Wed Jul 29 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-2mdv2010.0
+ Revision: 403724
- 9.6.1-P1

* Sat Jun 13 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.1-1mdv2010.0
+ Revision: 385642
- 9.6.1
- drop upstream implemented patches
- sync rediffed and added patches from fedora

* Sun Mar 08 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-5mdv2009.1
+ Revision: 352808
- fix #26641 (can start before name services are up)
- sync with bind-9.6.0-7.P1.fc11

* Sun Feb 01 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-4mdv2009.1
+ Revision: 336058
- added 4 patches from bind-9.6.0-4.P1.fc11.src.rpm

* Tue Jan 13 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-3mdv2009.1
+ Revision: 329224
- re-enable postgresql support
- enable statistics at http://127.0.0.1:5380/ only from 127.0.0.1 (via libxml2)

* Thu Jan 08 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-2mdv2009.1
+ Revision: 327072
- 9.6.0-P1 (security fix)

* Sun Jan 04 2009 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-1mdv2009.1
+ Revision: 324717
- 9.6.0
- disable postgresql support

* Wed Dec 17 2008 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-0.1.rc1.2mdv2009.1
+ Revision: 315205
- added P400 to fix build with -Werror=format-security (thanks fcrozat)
- rediffed fuzzy patches

* Wed Dec 03 2008 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-0.1.rc1.1mdv2009.1
+ Revision: 309647
- 9.6.0rc1
- rediff patches

* Fri Nov 07 2008 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-0.b1.1mdv2009.1
+ Revision: 300462
- 9.6.0b1

* Fri Oct 10 2008 Oden Eriksson <oeriksson@mandriva.com> 9.6.0-0.a1.1mdv2009.1
+ Revision: 291332
- 9.6.0a1
- enable gss
- rediffed P202,P209
- nuke obsolete patches (P2,P201,P203)

* Wed Sep 10 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-6mdv2009.0
+ Revision: 283490
- re-enable threading

* Sat Aug 02 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-5mdv2009.0
+ Revision: 260671
- 9.5.0-P2

* Wed Jul 09 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-4mdv2009.0
+ Revision: 232924
- 9.5.0-P1

* Mon Jun 02 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-3mdv2009.0
+ Revision: 214279
- bump release
- hard code %%{_localstatedir}/lib (easier for backports)

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

  + Thomas Backlund <tmb@mandriva.org>
    - update bogon_acl to version 6.3 27 MAY 2008

* Thu May 29 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-2mdv2009.0
+ Revision: 213150
- bump release
- 9.5.0

* Sun May 18 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-1.0.rc1.1mdv2009.0
+ Revision: 208773
- bump release

* Sun May 18 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.1.rc1.1mdv2009.0
+ Revision: 208763
- bump release

* Wed May 14 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.rc1.1mdv2009.0
+ Revision: 207028
- 9.5.0rc1

* Sat Apr 19 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b3.1mdv2009.0
+ Revision: 195776
- 9.5.0b3
- drop P207, does not apply anymore

* Thu Apr 17 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b2.4mdv2009.0
+ Revision: 195099
- revert the "conform to the 2008 specs (don't start the services per
  default)" changes and let this be handled some other way...

* Wed Mar 26 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b2.3mdv2008.1
+ Revision: 190295
- really don't start it per default

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b2.2mdv2008.1
+ Revision: 167702
- fix typo in the initscript and don't start it per default
- fixed dome rpmlint errors

* Mon Feb 11 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b2.1mdv2008.1
+ Revision: 165036
- 9.5.0b2
- rediffed P211
- dropped upstream implemented patches; P214,P216

* Fri Feb 08 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b1.3mdv2008.1
+ Revision: 164047
- use S11 from ftp://ftp.internic.net/domain/named.cache instead, it has the ipv6 entries needed

* Thu Jan 24 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b1.2mdv2008.1
+ Revision: 157328
- security fix for CVE-2008-0122

* Wed Jan 09 2008 Oden Eriksson <oeriksson@mandriva.com> 9.5.0-0.b1.1mdv2008.1
+ Revision: 147342
- correct the release number
- 9.5.0b1, sync with fc except the dbus stuff

* Mon Dec 24 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.2-2mdv2008.1
+ Revision: 137454
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Nov 29 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.2-1mdv2008.1
+ Revision: 113927
- 9.4.2
- drop obsolete patches; P1,P2

* Sat Nov 17 2007 Funda Wang <fwang@mandriva.org> 9.4.1-9mdv2008.1
+ Revision: 109296
- rebuild for new lzma

* Sat Nov 03 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-8mdv2008.1
+ Revision: 105526
- the L.ROOT-SERVERS.NET. root server has a new ip address (199.7.83.42)
- move queryperf to the bind-utils subpackage
- added query-loc to the bind-utils subpackage
- moved the docs to the bind-doc subpackage

* Tue Sep 25 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-7mdv2008.0
+ Revision: 92757
- the lsm feature in the 2008 kernel and using the capability module seems fishy...,
  therefore both --disable-linux-caps *and* --disable-threads has to be used in order
  to able to run bind as non root.

* Thu Sep 06 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-6mdv2008.0
+ Revision: 80872
- fix #33168 (log file are not rotated because of new chroot)
- the previous release also fixed #31393 (bind can't resolv all domains on CS4)

* Thu Sep 06 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-5mdv2008.0
+ Revision: 80849
- added the config under version control and added some props as well

* Wed Jul 25 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-4mdv2008.0
+ Revision: 55463
- fix build
- 9.4.1-P1 (fixes CVE-2007-2925)

* Fri Jun 22 2007 Andreas Hasenack <andreas@mandriva.com> 9.4.1-3mdv2008.0
+ Revision: 43307
- using new serverbuild macro which includes -fstack-protector

* Fri Jun 08 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-2mdv2008.0
+ Revision: 37289
- added P2 to make it shut up about "... is using obsolete setsockopt SO_BSDCOMPAT"
- use the %%serverbuild macro
- use distro conditional -fstack-protector

* Tue May 08 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.1-1mdv2008.0
+ Revision: 25081
- 9.4.1 (fixes CVE-2007-2241)

* Wed Apr 18 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-4mdv2008.0
+ Revision: 14521
- added GeoIP support (P300) (disabled per default)


* Wed Mar 28 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-3mdv2007.1
+ Revision: 149234
- fix the lsb stuff in the init script

* Wed Mar 14 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-2mdv2007.1
+ Revision: 143465
- sync with fedora (P205,P206 from 9.4.0-2.fc7)

* Wed Feb 28 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-1mdv2007.1
+ Revision: 127303
- 9.4.0

* Wed Feb 28 2007 Guillaume Rousse <guillomovitch@mandriva.org> 9.4.0-0.rc2.2mdv2007.1
+ Revision: 127270
- use saner default perms for chroot

* Wed Jan 31 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-0.rc2.1mdv2007.1
+ Revision: 115663
- 9.4.0rc2 (security fixes)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 9.4.0-0.rc1.2mdv2007.1
+ Revision: 111121
- provide the named system facility (#25935)

* Sat Jan 13 2007 Christiaan Welvaart <spturtle@mandriva.org> 9.4.0-0.rc1.1mdv2007.1
+ Revision: 108173
- patch204: fix ppc asm syntax

* Wed Jan 10 2007 Oden Eriksson <oeriksson@mandriva.com> 9.4.0-0.rc1.0mdv2007.1
+ Revision: 107200
- 9.4.0rc1 (fixes #28023 ?)
- fix #27981 (S10)
- updated the default configuration (S10)
- rediffed P0

* Fri Jan 05 2007 Oden Eriksson <oeriksson@mandriva.com> 9.3.3-1mdv2007.1
+ Revision: 104502
- 9.3.3

* Thu Nov 16 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-12mdv2007.1
+ Revision: 84987
- need to use "--enable-threads" in order to make the server threaded,
  build a special non-threaded host command. second attempt to fix #16855
- since we're using /dev/urandom per default now the initscript need to create it for the chroot

* Wed Nov 15 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-11mdv2007.1
+ Revision: 84350
- 9.3.2-P2, fixes #27174 (CVE-2006-4339)
- drop upstream CVE-2006-409[56] fixes (P204)
- make it use /dev/urandom per default

* Sat Oct 14 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-10mdv2007.1
+ Revision: 64678
- remove bzip files
- fix #26529

* Wed Oct 11 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-9mdv2007.1
+ Revision: 63298
- bunzip sources and patches
- Import bind

* Fri Sep 08 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-8mdv2007.0
- plug CVE-2006-409[56] (#25294)

* Sat Aug 05 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-7mdv2007.0
- disable threading support (fixes #16855)

* Wed Jun 07 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-5mdk
- add a simple hosts file, needed by ldap (Andreas Hasenack)

* Wed May 24 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-5mdk
- make it use chroot per default (#22390)
- added some caching-server config from fedora
- cleaned the init script and added a pinit entry
- added changes to the initscript (Andreas Hasenack)

* Wed May 03 2006 Andreas Hasenack <andreas@mandriva.com> 9.3.2-4mdk
- added patch to make zonetoldap use LDAPv3 instead of LDAPv2

* Fri Feb 10 2006 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-3mdk
- use modprobe to load capability (#21043) (Andreas Hasenack)

* Sat Dec 31 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-2mdk
- just a safe guard: check if we need to load the capability kernel module.
  MDK has this builtin, but some user might rebuild the kernel and use it
  as a module (S4) (Andreas Hasenack)

* Wed Dec 21 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-1mdk
- 9.3.2

* Mon Dec 19 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-0.rc1.1mdk
- 9.3.2rc1

* Mon Nov 14 2005 Leonardo Chiquitto <chiquitto@mandriva.com> 9.3.2-0.b2.3mdk
- bind-chroot.sh: move /var/run/named to the chroot, even when named isn't
  running

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-0.b2.2mdk
- rebuilt against openssl-0.9.8a

* Thu Oct 27 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-0.b2.1mdk
- 9.3.2b2
- rediffed P0

* Sun Oct 02 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.2-0.b1.1mdk
- 9.3.2b1
- rediffed P0,P202
- drop upstream implemented patch (P204)
- use -DLDAP_DEPRECATED when building the thing
- re-add missing code from 9.3.1 (S16)

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.1-4mdk
- rebuilt against new openldap-2.3.6 libs

* Sun Aug 28 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.1-3mdk
- fix compilation of the queryperf util
- fix deps

* Mon Jun 20 2005 Oden Eriksson <oeriksson@mandriva.com> 9.3.1-2mdk
- added the contrib stuff from the original sources (S13,S14)
  and also add the corresponding url to where these resides. ie.
  don't use the bundled code...
- added P203,P204 from fedora (9.3.1-6)
- added the new ldap2zone tool (S15)
- combined two fedora patches into the new P101

* Fri Mar 11 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.1-1mdk
- 9.3.1
- use the %%mkrel macro

* Wed Feb 16 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.1-0.rc1.1mdk
- 9.3.1rc1
- dropped upstream implemented P4 (VU_938617)
- deactivated P201, another fix is implemented upstream as far as
  i could tell

* Mon Feb 14 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-7mdk
- remove stuff in %%post, such as an upgrade from bind 4.9.x (we 
  have never had such old stuff in here...)
- people running bind 4.9.x would know what to do when "upgrading"
  to this version...
- don't run the intrusive update_bind.pl in %%post, fixes ancient #10043
- fix misc rpmlint errors
- fix #10043
- strip away annoying ^M

* Fri Feb 04 2005 Buchan Milne <bgmilne@linux-mandrake.com> 9.3.0-6mdk
- rebuild for ldap2.2_7

* Fri Jan 28 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-5mdk
- security update for CERT VU#938617
- fix deps and conditional %%multiarch

* Sun Dec 26 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-4mdk
- fix deps, autoconf2.1 is implied anyway with the %%configure macro, this
  makes it easier to "backport" bind.
- drop unused patches, renumber patches and sources, rename and bzip sources.
- added supported rndc commands to the sysv script and also make it accept 
  arguments, for example "service named reload nux.se" will reload only 
  the "nux.se" zone.
- added P200 - P202 from fedora
- run the test suite (make check)
- make lwresd soft link to named instead of a hard link

* Tue Oct 05 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-3mdk
- touched S7 and and added stuff from trustix to it

* Thu Sep 30 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 9.3.0-2mdk
- fix detection of res_mkquery(), aka fix build on e.g. x86_64

* Fri Sep 24 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-1mdk
- 9.3.0

* Sun Sep 05 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-0.rc4.1mdk
- 9.3.0rc4
- drop P3, it's fixed upstream :)
- fix slight man page mess

* Wed Aug 18 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-0.rc3.1mdk
- 9.3.0rc3

* Sun Aug 01 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-0.rc2.3mdk
- added the mysql sdb driver (S12 & P102), thanks to Michael Scherer for
  helping with the contitional build stuff.
- rename zone2ldap to zonetoldap as it clashes with PowerDNS
- misc spec file fixes

* Wed Jul 14 2004 Florin <florin@mandrakesoft.com> 9.3.0-0.rc2.2mdk
- update description (without sdb_ldap)

* Tue Jul 13 2004 Florin <florin@mandrakesoft.com> 9.3.0-0.rc2.1mdk
- 9.3.0rc2
- update some patches
- comment out the broken queryperf from contrib for now

* Fri Jun 18 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-0.beta2.6mdk
- update description (Tibor Pittich)

* Thu Jun 17 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 9.3.0-0.beta2.5mdk
- S11 was outdated as pointed out by Olivier Thauvin, fixed with a twist.
- added P6
- use some more aclocal and autoconf magic
- fix deps

* Sun Jun 13 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 9.3.0-0.beta2.4mdk
- removed build-dependency on bind-devel for zone2ldap

* Wed Jun 09 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 9.3.0-0.beta2.3mdk
- fix buildrequires
- cleanups!

* Thu May 27 2004 Buchan Milne <bgmilne@linux-mandrake.com> 9.3.0-0.beta2.2mdk
- make sdb_ldap work again (and enable by default)
- add zone2ldap and man page when building with sdb_ldap

* Wed Apr 21 2004 Florin <florin@mandrakesoft.com> 9.3.0-0.beta2.1mdk
- 9.3.0beta2
- update the fallback-to-second-server patch

